@@ -9,7 +9,7 @@
 # messages printed. Takes an optional logfile as first command
 # line parameter
 
-from __future__ import print_function
+
 
 import os
 import sys
@@ -139,10 +139,10 @@ class Logger:
         # type: (Text) -> None
         oname = name + '.old'
         try:
-            rename(name, oname)
+            rename(hglib.fromunicode(name), hglib.fromunicode(oname))
         except:
             pass
-        self.file = posixfile(name, b'wb')
+        self.file = posixfile(hglib.fromunicode(name), b'wb')
         self.msg('%s, Version %s' % (APP_TITLE, version.version()))
         self.msg('Logging to file started')
 
@@ -344,7 +344,7 @@ def getrepos(batch):
             except Exception as e:
                 # This exception raises in case of fixutf8 extension enabled
                 # and folder name contains '0x5c'(backslash).
-                logger.msg('Failed listdir %s (%s)' % (path, str(e)))
+                logger.msg('Failed listdir %s (%s)' % (path, hglib.exception_str(e)))
         else:
             roots.add(r)
             notifypaths.add(path)
@@ -382,7 +382,7 @@ def update_batch(batch):
                     failedroots.add(r)
                 except (error.Abort, error.ConfigError, error.RepoError,
                         error.RevlogError, ImportError) as e:
-                    logger.msg('Failed updating %s (%s)' % (r, str(e)))
+                    logger.msg('Failed updating %s (%s)' % (r, hglib.exception_str(e)))
                     failedroots.add(r)
             notifypaths -= failedroots
             if notifypaths:
@@ -410,34 +410,36 @@ def get_config():
         OpenKey = winreg.OpenKey
         QueryValueEx = winreg.QueryValueEx
 
-        hkey = OpenKey(HKEY_CURRENT_USER, r'Software\TortoiseHg')
-        t = ('1', 'True')
-        try: show_taskbaricon = QueryValueEx(hkey, 'ShowTaskbarIcon')[0] in t
-        except EnvironmentError: pass
-        try: hgighlight_taskbaricon = QueryValueEx(hkey, 'HighlightTaskbarIcon')[0] in t
-        except EnvironmentError: pass
+        with OpenKey(HKEY_CURRENT_USER, r'Software\TortoiseHg') as hkey:
+            t = ('1', 'True')
+            try: show_taskbaricon = QueryValueEx(hkey, 'ShowTaskbarIcon')[0] in t
+            except OSError: pass
+            try: hgighlight_taskbaricon = QueryValueEx(hkey, 'HighlightTaskbarIcon')[0] in t
+            except OSError: pass
 
-        # Upgrade user's context menu, once per major release
-        try: version2cmenu = QueryValueEx(hkey, 'ContextMenuVersion')[0] == '2'
-        except EnvironmentError: pass
-        try:
-            if not version2cmenu:
-                CreateKey = winreg.CreateKey
-                SetValueEx = winreg.SetValueEx
-                REG_SZ = winreg.REG_SZ
+            # Upgrade user's context menu, once per major release
+            try: version2cmenu = QueryValueEx(hkey, 'ContextMenuVersion')[0] == '2'
+            except OSError: pass
 
-                try: promoted = QueryValueEx(hkey, 'PromotedItems')[0]
-                except EnvironmentError: promoted = ''
-                plist = [i.strip() for i in promoted.split(',')]
-                hkey = CreateKey(HKEY_CURRENT_USER, r'Software\TortoiseHg')
-                if u'log' in plist:
-                    idx = plist.index(u'log')
-                    plist[idx] = u'workbench'
-                    SetValueEx(hkey, 'PromotedItems', 0, REG_SZ, ','.join(plist))
-                SetValueEx(hkey, 'ContextMenuVersion', 0, REG_SZ, '2')
-        except EnvironmentError:
-            pass
-    except (ImportError, WindowsError):
+            try:
+                if not version2cmenu:
+                    CreateKey = winreg.CreateKey
+                    SetValueEx = winreg.SetValueEx
+                    REG_SZ = winreg.REG_SZ
+
+                    try: promoted = QueryValueEx(hkey, 'PromotedItems')[0]
+                    except OSError: promoted = ''
+                    plist = [i.strip() for i in promoted.split(',')]
+
+                    with CreateKey(HKEY_CURRENT_USER, r'Software\TortoiseHg') as hkey2:
+                        if u'log' in plist:
+                            idx = plist.index(u'log')
+                            plist[idx] = u'workbench'
+                            SetValueEx(hkey2, 'PromotedItems', 0, REG_SZ, ','.join(plist))
+                        SetValueEx(hkey2, 'ContextMenuVersion', 0, REG_SZ, '2')
+            except OSError:
+                pass
+    except (ImportError, OSError):
         pass
     return show_taskbaricon, hgighlight_taskbaricon
 
@@ -481,12 +483,13 @@ def remove(args):
     if roots:
         for r in sorted(roots):
             tfn = os.path.join(r, '.hg', 'thgstatus')
+            fn = hglib.fromunicode(tfn)
             try:
-                f = posixfile(tfn, b'rb')
+                f = posixfile(fn, b'rb')
                 e = f.readline()
                 f.close()
                 if not e.startswith(b'@@noicons'):
-                    unlink(tfn)
+                    unlink(fn)
             except (IOError, OSError) as e:
                 if e.errno != errno.ENOENT:
                     logger.msg("Error while trying to remove %s (%s)" % (tfn, e))
