@@ -5,12 +5,6 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
-
-from mercurial import (
-    pycompat,
-)
-
 from tortoisehg.hgqt.qtcore import (
     QObject,
 )
@@ -81,7 +75,7 @@ class BaseMenuActions(QObject):
         newtext, ok = QInputDialog.getText(self._parentWidget(), title, label,
                                            QLineEdit.EchoMode.Normal, text or '')
         if ok:
-            return pycompat.unicode(newtext)
+            return newtext
 
     def _log(self, msg, label=b'ui.debug'):
         try:
