@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+
 
 import time
 import unittest
@@ -49,7 +49,7 @@ class PatchQueueModelTest(unittest.TestCase):
             loop = QEventLoop()
             self.repoagent.serviceStopped.connect(loop.quit)
             QTimer.singleShot(5000, loop.quit)  # timeout
-            loop.exec_()
+            loop.exec()
 
     def indexForPatch(self, patch):
         m = self.model
@@ -63,7 +63,7 @@ class PatchQueueModelTest(unittest.TestCase):
         timer.timeout.connect(loop.quit)
         timer.start()
         while self.repoagent.isBusy() and timer.isActive():
-            loop.exec_()
+            loop.exec()
         self.assertFalse(self.repoagent.isBusy(), 'timeout while busy')
 
     def test_patchname(self):
