@@ -12,15 +12,13 @@ script that THG has borrowed from the TortoiseSVN project.
 This script is quite useless outside of a TortoiseHg binary install.
 '''
 
-from __future__ import print_function
+
 
 import os
 import sys
 import subprocess
 import shutil
 import win32con  # pytype: disable=import-error
-import win32api  # pytype: disable=import-error
-import win32process  # pytype: disable=import-error
 import locale
 
 from mercurial import (
@@ -74,13 +72,7 @@ def main():
         print('Unsupported file type', ext)
         sys.exit(1)
 
-    proc = win32api.GetCurrentProcess()
-    try:
-        # This will fail on windows < NT
-        filename = win32process.GetModuleFileNameEx(proc, 0)
-    except:
-        filename = win32api.GetModuleFileName(0)
-    path = os.path.join(os.path.dirname(filename), 'diff-scripts')
+    path = os.path.join(os.path.dirname(sys.executable), 'diff-scripts')
     if not os.path.isdir(path):
         print('Diff scripts not found at', path)
         sys.exit(1)
